#
# rhevm-setup-plugins -- ovirt engine setup
# Copyright (C) 2013 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


"""Constants for RHEL-related flows."""


import os
import gettext
_ = lambda m: gettext.dgettext(message=m, domain='rhevm-setup-plugins')


from otopi import util


from constants import osetupattrsclass
from constants import osetupattrs


from . import constants as osetupcons


@util.export
@util.codegen
@osetupattrsclass
class Const(object):
    # FIXME: this URL it's package dependent,
    # try to have some kind of generic indexing for it
    UPGRADE_KB_URL = 'https://access.redhat.com/site/articles/882773'
    INSTALL_G_URL = (
        'https://access.redhat.com/site/documentation/en-US/Red_'
        'Hat_Enterprise_Virtualization/{version}/html/Installation_'
        'Guide/index.html'
    ).format(
        version='.'.join(
            osetupcons.Const.PACKAGE_VERSION.split('.')[:2]
        ),
    )


@util.export
@util.codegen
class FileLocations(object):
    REDHAT_SUPPORT_PLUGIN_CONFIG = os.path.join(
        osetupcons.FileLocations.OVIRT_ENGINE_SYSCONFDIR,
        'redhatsupportplugin.conf'
    )
    DWH_INSTALLATION_FOLDER = os.path.join(
        osetupcons.FileLocations.DATADIR,
        'ovirt-engine-dwh'
    )
    REPORTS_INSTALLATION_FOLDER = os.path.join(
        osetupcons.FileLocations.DATADIR,
        'ovirt-engine-reports'
    )
    LEGACY_DWH_CONFIG = os.path.join(
        osetupcons.FileLocations.OVIRT_ENGINE_SYSCONFDIR,
        'ovirt-engine-dwh',
        'Default.properties'
    )
    LEGACY_REPORTS_BUILD_CONF_DEFAULT_DEV = os.path.join(
        osetupcons.FileLocations.DATADIR,
        'jasperreports-server-pro',
        'buildomatic',
        'build_conf',
        'default',
        'dev'
    )


@util.export
@util.codegen
@osetupattrsclass
class RedHatSupportPluginEnv(object):

    @osetupattrs(
        answerfile=True,
        postinstallfile=True,
    )
    def CONFIGURE(self):
        return 'OVESETUP_RHEVM_SUPPORT/configureRedhatSupportPlugin'

    @osetupattrs(
        answerfile=True,
    )
    def PROXY_ENABLED(self):
        return 'OVESETUP_RHEVM_SUPPORT/redhatSupportProxyEnabled'

    @osetupattrs(
        answerfile=True,
    )
    def PROXY(self):
        return 'OVESETUP_RHEVM_SUPPORT/redhatSupportProxy'

    @osetupattrs(
        answerfile=True,
    )
    def PROXY_PORT(self):
        return 'OVESETUP_RHEVM_SUPPORT/redhatSupportProxyPort'

    @osetupattrs(
        answerfile=True,
    )
    def PROXY_USER(self):
        return 'OVESETUP_RHEVM_SUPPORT/redhatSupportProxyUser'

    @osetupattrs(
        answerfile=True,
    )
    def PROXY_PASSWORD(self):
        return 'OVESETUP_RHEVM_SUPPORT/redhatSupportProxyPassword'


@util.export
@util.codegen
@osetupattrsclass
class DialogEnv(object):
    @osetupattrs(
        answerfile=True,
    )
    def CONFIRM_UPGRADE(self):
        return 'OVESETUP_RHEVM_DIALOG/confirmUpgrade'


@util.export
@util.codegen
@osetupattrsclass
class DWHCoreEnv(object):
    """Sync with ovirt-dwh"""

    ENABLE = 'OVESETUP_DWH_CORE/enable'


@util.export
@util.codegen
@osetupattrsclass
class ReportsCoreEnv(object):
    """Sync with ovirt-reports"""

    ENABLE = 'OVESETUP_REPORTS_CORE/enable'


# vim: expandtab tabstop=4 shiftwidth=4
