#
# ovirt-engine-setup -- ovirt engine setup
# Copyright (C) 2013-2014 Red Hat, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


""" Show upgrade KB plugin."""


import gettext
_ = lambda m: gettext.dgettext(message=m, domain='ovirt-engine-setup')


from otopi import util
from otopi import plugin


from ovirt_engine_setup import constants as osetupcons
from ovirt_engine_setup import rhevm_constants as rhevmcons
from ovirt_engine_setup import dialog


@util.export
class Plugin(plugin.PluginBase):
    """ Show upgrade KB plugin."""

    def __init__(self, context):
        super(Plugin, self).__init__(context=context)
        self._enabled = True

    @plugin.event(
        stage=plugin.Stages.STAGE_INIT,
    )
    def _init(self):
        self.environment.setdefault(
            rhevmcons.DialogEnv.CONFIRM_UPGRADE,
            True
        )

    @plugin.event(
        stage=plugin.Stages.STAGE_CUSTOMIZATION,
        priority=plugin.Stages.PRIORITY_FIRST,
    )
    def _customization(self):
        if (
            self.environment[
                rhevmcons.DialogEnv.CONFIRM_UPGRADE
            ] and
            not self.environment[
                osetupcons.DBEnv.NEW_DATABASE
            ]
        ):
            self.dialog.note(
                text=_(
                    '\n'
                    'Welcome to the RHEV {new_version} upgrade.\n'
                    'Please read the RHEV {new_version} install guide\n'
                    '{inst_url}\n'
                    'and the RHEV {new_version} Upgrade Guide: Tips, '
                    'Considerations and Roll-back Issues article\n'
                    '{kb_url}\n'
                    'before proceeding with the upgrade.\n'
                ).format(
                    new_version='.'.join(
                        osetupcons.Const.PACKAGE_VERSION.split('.')[:2]
                    ),
                    inst_url=rhevmcons.Const.INSTALL_G_URL,
                    kb_url=rhevmcons.Const.UPGRADE_KB_URL,
                ),
            )
            if not dialog.queryBoolean(
                dialog=self.dialog,
                name='OVESETUP_DIALOG_CONTINUE_UPGRADE',
                note=_(
                    'Would you like to continue with the upgrade? '
                    '(@VALUES@) [@DEFAULT@]: '
                ),
                prompt=True,
                true=_('Yes'),
                false=_('No'),
                default=True,
            ):
                raise RuntimeError(
                    _('Upgrade aborted.')
                )
            self.environment[rhevmcons.DialogEnv.CONFIRM_UPGRADE] = False


# vim: expandtab tabstop=4 shiftwidth=4
